#**************************************************************
# Time Information
#**************************************************************

set_time_format -unit ns -decimal_places 3


#**************************************************************
# Create Clock
#**************************************************************
create_clock -name encodeClock -period "180.0 MHz" [get_ports ENCODE_CLOCK]

# Based on ADC timing specifications
create_generated_clock -name adc2ChClockout -source [get_ports {ENCODE_CLOCK}] -offset 1.6 -invert [get_ports {ADC_2CH_CLKOUT}]
create_generated_clock -name adc1ChClockout -source [get_ports {ENCODE_CLOCK}] -offset 1.6 -invert [get_ports {ADC_1CH_CLKOUT}]


#**************************************************************
# Create Generated Clock
#**************************************************************

# ADC PLL clocks must be derived manually due to a bug in Quartus, see https://www.intel.com/content/www/us/en/programmable/support/support-resources/knowledge-base/solutions/rd06082014_23.html

create_generated_clock -name {adcPll_1Ch_inst|adcpll_inst|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk} -source [get_pins {adcPll_1Ch_inst|adcpll_inst|altera_pll_i|general[0].gpll~FRACTIONAL_PLL|refclkin}] -duty_cycle 50.000 -multiply_by 1 -divide_by 1 -phase 89.887 -master_clock {adc1ChClockout} [get_pins {adcPll_1Ch_inst|adcpll_inst|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}] 
create_generated_clock -name {adcPll_2Ch_inst|adcpll_inst|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk} -source [get_pins {adcPll_2Ch_inst|adcpll_inst|altera_pll_i|general[0].gpll~FRACTIONAL_PLL|refclkin}] -duty_cycle 50.000 -multiply_by 1 -divide_by 1 -phase 89.887 -master_clock {adc2ChClockout} [get_pins {adcPll_2Ch_inst|adcpll_inst|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}] 

derive_pll_clocks


#**************************************************************
# Set Clock Latency
#**************************************************************

# Based on ADC timing specifications

set_clock_latency -source -early -0.3 [get_clocks {adc2ChClockout}]
set_clock_latency -source -late 0.2 [get_clocks {adc2ChClockout}]
set_clock_latency -source -early -0.3 [get_clocks {adc1ChClockout}]
set_clock_latency -source -late 0.2 [get_clocks {adc1ChClockout}]



#**************************************************************
# Set Clock Uncertainty
#**************************************************************

derive_clock_uncertainty



#**************************************************************
# Set Input Delay
#**************************************************************

# Based on ADC timing specifications

set_input_delay -min -clock [get_clocks {adc2ChClockout}] 0.3 [get_ports ADC_2CH_DATA*] -add_delay
set_input_delay -min -clock [get_clocks {adc2ChClockout}] 0.3 [get_ports ADC_2CH_DATA*] -clock_fall -add_delay
set_input_delay -max -clock [get_clocks {adc2ChClockout}] 0.55 [get_ports ADC_2CH_DATA*] -add_delay
set_input_delay -max -clock [get_clocks {adc2ChClockout}] 0.55 [get_ports ADC_2CH_DATA*] -clock_fall -add_delay

set_input_delay -min -clock [get_clocks {adc1ChClockout}] 0.3 [get_ports ADC_1CH_DATA*] -add_delay
set_input_delay -min -clock [get_clocks {adc1ChClockout}] 0.3 [get_ports ADC_1CH_DATA*] -clock_fall -add_delay
set_input_delay -max -clock [get_clocks {adc1ChClockout}] 0.55 [get_ports ADC_1CH_DATA*] -add_delay
set_input_delay -max -clock [get_clocks {adc1ChClockout}] 0.55 [get_ports ADC_1CH_DATA*] -clock_fall -add_delay



#**************************************************************
# Set Output Delay
#**************************************************************



#**************************************************************
# Set Clock Groups
#**************************************************************



#**************************************************************
# Set False Path
#**************************************************************

set_false_path -to [get_clocks {systemPll_inst|systempll_inst|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}]

set_false_path -setup -fall_from [get_clocks {adc2ChClockout}] -rise_to [get_clocks {adc2ChClockout}]
set_false_path -setup -rise_from [get_clocks {adc2ChClockout}] -fall_to [get_clocks {adc2ChClockout}]
set_false_path -hold -fall_from [get_clocks {adc2ChClockout}] -fall_to [get_clocks {adc2ChClockout}]
set_false_path -hold -rise_from [get_clocks {adc2ChClockout}] -rise_to [get_clocks {adc2ChClockout}]

set_false_path -setup -fall_from [get_clocks {adc1ChClockout}] -rise_to [get_clocks {adc1ChClockout}]
set_false_path -setup -rise_from [get_clocks {adc1ChClockout}] -fall_to [get_clocks {adc1ChClockout}]
set_false_path -hold -fall_from [get_clocks {adc1ChClockout}] -fall_to [get_clocks {adc1ChClockout}]
set_false_path -hold -rise_from [get_clocks {adc1ChClockout}] -rise_to [get_clocks {adc1ChClockout}]



#**************************************************************
# Set Multicycle Path
#**************************************************************

# Set multicycle to 0 to capture at same edge
set_multicycle_path -setup -rise_from [get_clocks {adc1ChClockout}] -rise_to [get_clocks {adc1ChClockout}] 0
set_multicycle_path -setup -fall_from [get_clocks {adc1ChClockout}] -fall_to [get_clocks {adc1ChClockout}] 0

set_multicycle_path -setup -rise_from [get_clocks {adc2ChClockout}] -rise_to [get_clocks {adc2ChClockout}] 0
set_multicycle_path -setup -fall_from [get_clocks {adc2ChClockout}] -fall_to [get_clocks {adc2ChClockout}] 0

 
#**************************************************************
# Set Maximum Delay
#**************************************************************



#**************************************************************
# Set Minimum Delay
#**************************************************************



#**************************************************************
# Set Input Transition
#**************************************************************



#**************************************************************
# Set Load
#**************************************************************
